@@ -716,9 +716,6 @@ LOAD_TYPE(TPMT_TK_CREATION, creation_ticket)
 SAVE_TYPE(TPM2B_DIGEST, digest)
 LOAD_TYPE(TPM2B_DIGEST, digest)
 
-SAVE_TYPE(TPM2B_ATTEST, attestation)
-LOAD_TYPE(TPM2B_ATTEST, attestation)
-
 SAVE_TYPE(TPM2B_CREATION_DATA, creation_data)
 LOAD_TYPE(TPM2B_CREATION_DATA, creation_data)
 
