@@ -294,6 +294,9 @@ tool_rc tpm2_nvglobalwritelock(ESYS_CONTEXT *esys_context,
 tool_rc tpm2_nvwritelock(ESYS_CONTEXT *esys_context,
         tpm2_loaded_object *auth_hierarchy_obj, TPM2_HANDLE nv_index);
 
+tool_rc tpm2_tr_from_tpm_public(ESYS_CONTEXT *esys_context,
+        TPM2_HANDLE handle, ESYS_TR *tr_handle);
+
 tool_rc tpm2_nvsetbits(ESYS_CONTEXT *esys_context,
         tpm2_loaded_object *auth_hierarchy_obj, TPM2_HANDLE nv_index,
         UINT64 bits);
