@@ -38,8 +38,9 @@ tool_rc tpm2_policy_build_pcr(ESYS_CONTEXT *context,
  *   The policy session that has the policy digest to be authorized
  * @param policy_digest_path
  *   The policy digest file that needs to be authorized by signing authority
- * @param policy_qualifier_path
- *   The policy qualifier data that concatenates with approved policies
+ * @param policy_qualifier
+ *   The policy qualifier data that concatenates with approved policies. Can be
+ *   either a path to a file or a hex string.
  * @param verifying_pubkey_name_path
  *   The name of the public key that verifies the signature of the signer
  * @param ticket_path
@@ -49,7 +50,7 @@ tool_rc tpm2_policy_build_pcr(ESYS_CONTEXT *context,
  */
 tool_rc tpm2_policy_build_policyauthorize(ESYS_CONTEXT *ectx,
         tpm2_session *policy_session, const char *policy_digest_path,
-        const char *policy_qualifier_path,
+        const char *policy_qualifier,
         const char *verifying_pubkey_name_path, const char *ticket_path);
 
 /**
@@ -68,6 +69,37 @@ tool_rc tpm2_policy_build_policyauthorize(ESYS_CONTEXT *ectx,
 tool_rc tpm2_policy_build_policyor(ESYS_CONTEXT *ectx,
         tpm2_session *policy_session, TPML_DIGEST *policy_list);
 
+/**
+ * Evaluates an authorization for specific named objects.
+ *
+ * @param ectx
+ *  The Enhanced system api context
+ * @param session
+ *  The policy session into which the policy digest is extended into
+ * @param name_hash
+ *  The name hash
+ *
+ * @return
+ *   tool_rc indicating status.
+ */
+tool_rc tpm2_policy_build_policynamehash(ESYS_CONTEXT *ectx,
+    tpm2_session *session, const TPM2B_DIGEST *name_hash);
+
+/**
+ * Evaluates an authorization for object's public template data digest.
+ *
+ * @param ectx
+ *  The Enhanced system api context
+ * @param session
+ *  The policy session into which the policy digest is extended into
+ * @param name_hash
+ *  The public template hash
+ *
+ * @return
+ *   tool_rc indicating status.
+ */
+tool_rc tpm2_policy_build_policytemplate(ESYS_CONTEXT *ectx,
+    tpm2_session *session, const TPM2B_DIGEST *template_hash);
 /**
  * Enables secret (password/hmac) based authorization to a policy.
  *
@@ -85,7 +117,10 @@ tool_rc tpm2_policy_build_policyor(ESYS_CONTEXT *ectx,
  *  tool_rc indicating status.
  */
 tool_rc tpm2_policy_build_policysecret(ESYS_CONTEXT *ectx,
-        tpm2_session *policy_session, tpm2_loaded_object *auth_entity_obj);
+        tpm2_session *policy_session, tpm2_loaded_object *auth_entity_obj,
+        INT32 expiration, TPMT_TK_AUTH **policy_ticket,
+        TPM2B_TIMEOUT **timeout, bool is_nonce_tpm,
+        const char *policy_qualifier_path);
 
 /**
  * Retrieves the policy digest for a session via PolicyGetDigest.
@@ -114,6 +149,61 @@ tool_rc tpm2_policy_get_digest(ESYS_CONTEXT *context, tpm2_session *session,
 tool_rc tpm2_policy_build_policypassword(ESYS_CONTEXT *ectx,
         tpm2_session *session);
 
+/**
+ * Enables a policy that requires the object's authvalue be provided.
+ * The authvalue can be transmitted as an HMAC
+ * @param ectx
+ *  The Enhanced system api (ESAPI_) context.
+ * @param session
+ *  The policy session which is extended with PolicyAuthValue command code
+ * @return
+ *  tool_rc indicating status.
+ */
+tool_rc tpm2_policy_build_policyauthvalue(ESYS_CONTEXT *ectx,
+        tpm2_session *session);
+
+/**
+ * Enables a policy authorization by virtue of verifying a signature on optional
+ * TPM2 parameters data - nonceTPM, cphashA, policyRef, expiration
+ * @param ectx
+ *  The Enhanced system api (ESAPI) context
+ * @param session
+ *  The policy session which is extended with PolicySigned command code
+ * @param auth_entity_obj
+ *  The loaded TPM2 key object public portion used for signature verification
+ * @param signature
+ *  The signature of the optional TPM2 parameters
+ */
+tool_rc tpm2_policy_build_policysigned(ESYS_CONTEXT *ectx,
+        tpm2_session *policy_session, tpm2_loaded_object *auth_entity_obj,
+        TPMT_SIGNATURE *signature, INT32 expiration, TPM2B_TIMEOUT **timeout,
+        TPMT_TK_AUTH **policy_ticket, const char *policy_qualifier_path,
+        bool is_nonce_tpm, const char *raw_data_path);
+
+/**
+ * PolicyTicket assertion enables proxy authentication for either PolicySecret
+ * or PolicySigned once the specific policy is validated.
+ *
+ * @param ectx
+ *  The Enhanced system api (ESAPI) context
+ * @param session
+ *  The policy session which is being extended
+ * @param policy_timeout_path
+ *  The file containing the timeout data generated PolicySigned/ PolicySecret
+ * @param qualifier_data_path
+ *  The file containing the qualifier data or policyRef
+  * @param policy_ticket_path
+ *  The file containing the auth ticket
+ * @param auth_name_file
+ *  The auth name file containing the name of the auth object
+ *
+ * @return     { description_of_the_return_value }
+ */
+tool_rc tpm2_policy_build_policyticket(ESYS_CONTEXT *ectx,
+    tpm2_session *policy_session, char *policy_timeout_path,
+    const char *qualifier_data_path, char *policy_ticket_path,
+    const char *auth_name_file);
+
 /**
  * Parses the policy digest algorithm for the list of policies specified
  *
@@ -141,6 +231,21 @@ bool tpm2_policy_parse_policy_list(char *str, TPML_DIGEST *policy_list);
 tool_rc tpm2_policy_build_policycommandcode(ESYS_CONTEXT *ectx,
         tpm2_session *session, uint32_t command_code);
 
+/**
+ * Policy to restrict authorization to written state of the NV Index
+ *
+ * @param ectx
+ *   The Enhanced system api (ESAPI_) context.
+ * @param policy_session
+ *   The policy session into which the policy digest is extended into
+ * @param written_set
+ *   SET/ CLEAR TPMI_YES_NO value of the expected written state of NV index
+ * @return
+ *  A tool_rc indicating status.
+ */
+tool_rc tpm2_policy_build_policynvwritten(ESYS_CONTEXT *ectx,
+        tpm2_session *session, TPMI_YES_NO written_set);
+
 /**
  * Policy to restrict tpm object authorization to specific locality
  *
