@@ -2,6 +2,7 @@
 
 #include <ctype.h>
 #include <dlfcn.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -16,142 +17,6 @@
 #include "tpm2_tool.h"
 #include "tpm2_util.h"
 
-bool tpm2_util_get_digest_from_quote(TPM2B_ATTEST *quoted, TPM2B_DIGEST *digest,
-        TPM2B_DATA *extra_data) {
-    TPM2_GENERATED magic;
-    TPMI_ST_ATTEST type;
-    UINT16 name_size = 0;
-    UINT32 i = 0;
-
-    // Ensure required headers are at least there
-    if (quoted->size < 6) {
-        LOG_ERR("Malformed TPM2B_ATTEST headers");
-        return false;
-    }
-
-    memcpy(&magic, &quoted->attestationData[i], 4);
-    i += 4;
-    memcpy(&type, &quoted->attestationData[i], 2);
-    i += 2;
-    if (!tpm2_util_is_big_endian()) {
-        magic = tpm2_util_endian_swap_32(magic);
-        type = tpm2_util_endian_swap_16(type);
-    }
-
-    if (magic != TPM2_GENERATED_VALUE) {
-        LOG_ERR("Malformed TPM2_GENERATED magic value");
-        return false;
-    }
-
-    if (type != TPM2_ST_ATTEST_QUOTE) {
-        LOG_ERR("Malformed TPMI_ST_ATTEST quote value");
-        return false;
-    }
-
-    // Qualified signer name (skip)
-    if (i + 2 >= quoted->size) {
-        LOG_ERR("Malformed TPM2B_NAME value");
-        return false;
-    }
-    memcpy(&name_size, &quoted->attestationData[i], 2);
-    i += 2;
-    if (!tpm2_util_is_big_endian()) {
-        name_size = tpm2_util_endian_swap_16(name_size);
-    }
-    i += name_size;
-
-    // Extra data (skip)
-    if (i + 2 >= quoted->size) {
-        LOG_ERR("Malformed TPM2B_DATA value");
-        return false;
-    }
-    memcpy(&extra_data->size, &quoted->attestationData[i], 2);
-    i += 2;
-    if (!tpm2_util_is_big_endian()) {
-        extra_data->size = tpm2_util_endian_swap_16(extra_data->size);
-    }
-    if (extra_data->size + i > quoted->size) {
-        LOG_ERR("Malformed extra_data TPM2B_DATA value");
-        return false;
-    }
-    memcpy(&extra_data->buffer, &quoted->attestationData[i], extra_data->size);
-    i += extra_data->size;
-
-    // Clock info (skip)
-    i += 17;
-    if (i >= quoted->size) {
-        LOG_ERR("Malformed TPMS_CLOCK_INFO value");
-        return false;
-    }
-
-    // Firmware info (skip)
-    i += 8;
-    if (i >= quoted->size) {
-        LOG_ERR("Malformed firmware version value");
-        return false;
-    }
-
-    // PCR select info
-    UINT8 sos;
-    TPMI_ALG_HASH hash_alg;
-    UINT32 pcr_select_count = 0, j = 0;
-    if (i + 4 >= quoted->size) {
-        LOG_ERR("Malformed TPML_PCR_SELECTION value");
-        return false;
-    }
-    memcpy(&pcr_select_count, &quoted->attestationData[i], 4);
-    i += 4;
-    if (!tpm2_util_is_big_endian()) {
-        pcr_select_count = tpm2_util_endian_swap_32(pcr_select_count);
-    }
-    for (j = 0; j < pcr_select_count; j++) {
-        // Hash
-        if (i + 2 >= quoted->size) {
-            LOG_ERR("Malformed TPMS_PCR_SELECTION value");
-            return false;
-        }
-        memcpy(&hash_alg, &quoted->attestationData[i], 2);
-        i += 2;
-        if (!tpm2_util_is_big_endian()) {
-            hash_alg = tpm2_util_endian_swap_16(hash_alg);
-        }
-
-        // SizeOfSelected
-        if (i + 1 >= quoted->size) {
-            LOG_ERR("Malformed TPMS_PCR_SELECTION value");
-            return false;
-        }
-        memcpy(&sos, &quoted->attestationData[i], 1);
-        i += 1;
-
-        // PCR Select (skip)
-        i += sos;
-        if (i >= quoted->size) {
-            LOG_ERR("Malformed TPMS_PCR_SELECTION value");
-            return false;
-        }
-    }
-
-    // Digest
-    if (i + 2 >= quoted->size) {
-        LOG_ERR("Malformed TPM2B_DIGEST value");
-        return false;
-    }
-    memcpy(&digest->size, &quoted->attestationData[i], 2);
-    i += 2;
-    if (!tpm2_util_is_big_endian()) {
-        digest->size = tpm2_util_endian_swap_16(digest->size);
-    }
-
-    if (digest->size + i > quoted->size) {
-        LOG_ERR("Malformed TPM2B_DIGEST value");
-        return false;
-    }
-    memcpy(&digest->buffer, &quoted->attestationData[i], digest->size);
-
-    return true;
-}
-
 // verify that the quote digest equals the digest we calculated
 bool tpm2_util_verify_digests(TPM2B_DIGEST *quoteDigest,
         TPM2B_DIGEST *pcr_digest) {
@@ -256,6 +121,67 @@ bool tpm2_util_string_to_uint32(const char *str, uint32_t *value) {
     return true;
 }
 
+bool tpm2_util_string_to_uint64(const char *str, uint64_t *value) {
+
+    char *endptr;
+
+    if (str == NULL || *str == '\0') {
+        return false;
+    }
+
+    /* clear errno before the call, should be 0 afterwards */
+    errno = 0;
+    /*
+     * unsigned long long is at least 64 bits, although commonly  just 64 bits even on 64 bit systems
+     * however, ensure that on some weird system it isn't greater than 64 bits since it is allowed by
+     * the standard.
+     */
+    unsigned long long int tmp = strtoull(str, &endptr, 0);
+    if (errno || tmp > UINT64_MAX) {
+        return false;
+    }
+
+    /*
+     * The entire string should be able to be converted or fail
+     * We already checked that str starts with a null byte, so no
+     * need to check that again per the man page.
+     */
+    if (*endptr != '\0') {
+        return false;
+    }
+
+    *value = (uint64_t) tmp;
+    return true;
+}
+
+bool tpm2_util_string_to_int32(const char *str, int32_t *value) {
+
+    char *endptr;
+
+    if (str == NULL || *str == '\0') {
+        return false;
+    }
+
+    /* clear errno before the call, should be 0 afterwards */
+    errno = 0;
+    signed long int tmp = strtol(str, &endptr, 0);
+    if (errno || tmp > INT32_MAX) {
+        return false;
+    }
+
+    /*
+     * The entire string should be able to be converted or fail
+     * We already checked that str starts with a null byte, so no
+     * need to check that again per the man page.
+     */
+    if (*endptr != '\0') {
+        return false;
+    }
+
+    *value = (int32_t) tmp;
+    return true;
+}
+
 int tpm2_util_hex_to_byte_structure(const char *input_string, UINT16 *byte_length,
         BYTE *byte_buffer) {
     int str_length; //if the input_string likes "1a2b...", no prefix "0x"
@@ -284,6 +210,27 @@ int tpm2_util_hex_to_byte_structure(const char *input_string, UINT16 *byte_lengt
     return 0;
 }
 
+bool tpm2_util_bin_from_hex_or_file(const char *input, UINT16 *len, BYTE *buffer) {
+
+    bool result = false;
+
+    FILE *f = fopen(input, "rb");
+    if (!f) {
+        result = tpm2_util_hex_to_byte_structure(input, len, buffer) == 0;
+        goto out;
+    }
+
+    result = file_read_bytes_from_file(f, buffer, len, input);
+    fclose(f);
+out:
+    if (!result) {
+        LOG_ERR("Could not convert \"%s\". Neither a file path nor hex string.",
+        input);
+    }
+
+    return result;
+}
+
 void tpm2_util_hexdump2(FILE *f, const BYTE *data, size_t len) {
 
     size_t i;
@@ -1021,3 +968,22 @@ bool tpm2_util_get_label(const char *value, TPM2B_DATA *label) {
 
     return true;
 }
+
+void tpm2_util_print_time(const TPMS_TIME_INFO *current_time) {
+
+    tpm2_tool_output("time: %"PRIu64"\n", current_time->time);
+
+    tpm2_tool_output("clock_info:\n");
+
+    tpm2_tool_output("  clock: %"PRIu64"\n",
+            current_time->clockInfo.clock);
+
+    tpm2_tool_output("  reset_count: %"PRIu32"\n",
+            current_time->clockInfo.resetCount);
+
+    tpm2_tool_output("  restart_count: %"PRIu32"\n",
+            current_time->clockInfo.restartCount);
+
+    tpm2_tool_output("  safe: %s\n",
+            current_time->clockInfo.safe ? "yes" : "no");
+}
