@@ -90,20 +90,6 @@ typedef struct {
 int tpm2_util_hex_to_byte_structure(const char *in_str, UINT16 *byte_length,
         BYTE *byte_buffer);
 
-/**
- * Pulls the TPM2B_DIGEST out of a TPM2B_ATTEST quote.
- * @param quoted
- *  The attestation quote structure.
-^ * @param digest
-^ *  The digest from the quote.
-^ * @param extra_data
-^ *  The extra_data from the quote.
- * @return
- *  True on success, false otherwise.
- */
-bool tpm2_util_get_digest_from_quote(TPM2B_ATTEST *quoted, TPM2B_DIGEST *digest,
-        TPM2B_DATA *extra_data);
-
 /**
  * Compares two digests to ensure they are equal (for validation).
  * @param quote_digest
@@ -127,6 +113,17 @@ bool tpm2_util_verify_digests(TPM2B_DIGEST *quote_digest,
  */
 bool tpm2_util_concat_buffer(TPM2B_MAX_BUFFER *result, TPM2B *append);
 
+/**
+ * Converts a numerical string into a int32_t value.
+ * @param str
+ *  The numerical string to convert.
+ * @param value
+ *  The value to store the conversion into.
+ * @return
+ *  true on success, false otherwise.
+ */
+bool tpm2_util_string_to_int32(const char *str, int32_t *value);
+
 /**
  * Converts a numerical string into a uint32 value.
  * @param str
@@ -138,6 +135,17 @@ bool tpm2_util_concat_buffer(TPM2B_MAX_BUFFER *result, TPM2B *append);
  */
 bool tpm2_util_string_to_uint32(const char *str, uint32_t *value);
 
+/**
+ * Converts a numerical string into a uint64 value.
+ * @param str
+ *  The numerical string to convert.
+ * @param value
+ *  The value to store the conversion into.
+ * @return
+ *  true on success, false otherwise.
+ */
+bool tpm2_util_string_to_uint64(const char *str, uint64_t *value);
+
 /**
  * Converts a numerical string into a uint16 value.
  * @param str
@@ -184,6 +192,20 @@ void tpm2_util_hexdump(const BYTE *data, size_t len);
  */
 void tpm2_util_hexdump2(FILE *f, const BYTE *data, size_t len);
 
+/**
+ * Read a hex string converting it to binary or a binary file and
+ * store into a binary buffer.
+ * @param input
+ *  Either a hex string or a file path.
+ * @param len
+ *  The maximum length of the buffer.
+ * @param buffer
+ *  The buffer to read into.
+ * @return
+ *  True on success, False otherwise.
+ */
+bool tpm2_util_bin_from_hex_or_file(const char *input, UINT16 *len, BYTE *buffer);
+
 /**
  * Prints a file as a hex string to stdout if quiet mode
  * is not enabled.
@@ -434,4 +456,11 @@ bool tpm2_util_handle_from_optarg(const char *value,
 
 bool tpm2_util_get_label(const char *value, TPM2B_DATA *label);
 
+/**
+ * Prints a TPMS_TIME_INFO in a YAML compliant format to stdout.
+ * @param current_time
+ *  The time structure to print
+ */
+void tpm2_util_print_time(const TPMS_TIME_INFO *current_time);
+
 #endif /* STRING_BYTES_H */
