@@ -18,11 +18,9 @@ typedef struct tpm2_verifysig_ctx tpm2_verifysig_ctx;
 struct tpm2_verifysig_ctx {
     union {
         struct {
-            UINT8 halg :1;
             UINT8 msg :1;
             UINT8 sig :1;
             UINT8 pcr :1;
-            UINT8 extra :1;
             UINT8 key_context :1;
             UINT8 fmt;
         };
@@ -32,8 +30,7 @@ struct tpm2_verifysig_ctx {
     TPMI_ALG_HASH halg;
     TPM2B_DIGEST msg_hash;
     TPM2B_DIGEST pcr_hash;
-    TPM2B_DIGEST quote_hash;
-    TPM2B_DATA quote_extra_data;
+    TPMS_ATTEST attest;
     TPM2B_DATA extra_data;
     TPMT_SIGNATURE signature;
     char *msg_file_path;
@@ -46,12 +43,9 @@ struct tpm2_verifysig_ctx {
 
 static tpm2_verifysig_ctx ctx = {
         .format = TPM2_ALG_ERROR,
-        .halg = TPM2_ALG_SHA1,
+        .halg = TPM2_ALG_SHA256,
         .msg_hash = TPM2B_TYPE_INIT(TPM2B_DIGEST, buffer),
         .pcr_hash = TPM2B_TYPE_INIT(TPM2B_DIGEST, buffer),
-        .quote_hash = TPM2B_TYPE_INIT(TPM2B_DIGEST, buffer),
-        .quote_extra_data = TPM2B_TYPE_INIT(TPM2B_DATA, buffer),
-        .extra_data = TPM2B_TYPE_INIT(TPM2B_DATA, buffer),
 };
 
 static bool verify_signature() {
@@ -92,18 +86,17 @@ static bool verify_signature() {
     }
 
     // Ensure nonce is the same as given
-    if (ctx.flags.extra) {
-        if (ctx.quote_extra_data.size != ctx.extra_data.size ||
-            memcmp(ctx.quote_extra_data.buffer, ctx.extra_data.buffer,
-            ctx.extra_data.size) != 0) {
-            LOG_ERR("Error validating nonce from quote");
-            goto err;
-        }
+    if (ctx.attest.extraData.size != ctx.extra_data.size ||
+        memcmp(ctx.attest.extraData.buffer, ctx.extra_data.buffer,
+        ctx.extra_data.size) != 0) {
+        LOG_ERR("Error validating nonce from quote");
+        goto err;
     }
 
     // Also ensure digest from quote matches PCR digest
     if (ctx.flags.pcr) {
-        if (!tpm2_util_verify_digests(&ctx.quote_hash, &ctx.pcr_hash)) {
+        if (!tpm2_util_verify_digests(&ctx.attest.attested.quote.pcrDigest,
+                &ctx.pcr_hash)) {
             LOG_ERR("Error validating PCR composite against signed message");
             goto err;
         }
@@ -212,10 +205,9 @@ out:
 static tool_rc init(void) {
 
     /* check flags for mismatches */
-    if (!(ctx.pubkey_file_path && ctx.flags.sig && ctx.flags.msg
-            && ctx.flags.halg)) {
+    if (!(ctx.pubkey_file_path && ctx.flags.sig && ctx.flags.msg)) {
         LOG_ERR(
-                "--pubkey (-c), --msg (-m), --halg (-g) and --sig (-s) are required");
+                "--pubkey (-u), --msg (-m) and --sig (-s) are required");
         return tool_rc_option_error;
     }
 
@@ -259,6 +251,14 @@ static tool_rc init(void) {
             goto err;
         }
 
+        if (pcr_select.count > TPM2_NUM_PCR_BANKS)
+            goto err;
+
+        UINT32 i;
+        for (i = 0; i < pcr_select.count; i++)
+            if (pcr_select.pcrSelections[i].hash == TPM2_ALG_ERROR)
+            goto err;
+
         if (!tpm2_openssl_hash_pcr_banks(ctx.halg, &pcr_select, &pcrs,
                 &ctx.pcr_hash)) {
             LOG_ERR("Failed to hash PCR values related to quote!");
@@ -270,10 +270,9 @@ static tool_rc init(void) {
         }
     }
 
-    // Figure out the extra data (nonce) from this message
-    if (!tpm2_util_get_digest_from_quote(msg, &ctx.quote_hash,
-            &ctx.quote_extra_data)) {
-        LOG_ERR("Failed to get digest from quote!");
+    tool_rc tmp_rc = files_tpm2b_attest_to_tpms_attest(msg, &ctx.attest);
+    if (tmp_rc != tool_rc_success) {
+        return_value = tmp_rc;
         goto err;
     }
 
@@ -305,7 +304,6 @@ static bool on_option(char key, char *value) {
             LOG_ERR("Unable to convert algorithm, got: \"%s\"", value);
             return false;
         }
-        ctx.flags.halg = 1;
     }
         break;
     case 'm': {
@@ -324,14 +322,9 @@ static bool on_option(char key, char *value) {
     }
         break;
     case 'q':
-        ctx.extra_data.size = sizeof(ctx.extra_data) - 2;
-        if (tpm2_util_hex_to_byte_structure(value, &ctx.extra_data.size,
-                ctx.extra_data.buffer) != 0) {
-            LOG_ERR("Could not convert \"%s\" from a hex string to byte array!",
-                    value);
-            return false;
-        }
-        ctx.flags.extra = 1;
+        ctx.extra_data.size = sizeof(ctx.extra_data.buffer);
+        return tpm2_util_bin_from_hex_or_file(value, &ctx.extra_data.size,
+                ctx.extra_data.buffer);
         break;
     case 's':
         ctx.sig_file_path = value;
