@@ -5,6 +5,7 @@
 
 #include "files.h"
 #include "log.h"
+#include "pcr.h"
 #include "tpm2.h"
 #include "tpm2_alg_util.h"
 #include "tpm2_auth_util.h"
@@ -31,12 +32,20 @@ struct tpm_create_ctx {
         char *private_path;
         char *auth_str;
         const char *ctx_path;
+        char *creation_data_file;
+        char *creation_ticket_file;
+        char *creation_hash_file;
+        char *template_data_path;
         char *alg;
         char *attrs;
         char *name_alg;
         char *policy;
     } object;
 
+    char *outside_info_data;
+
+    TPML_PCR_SELECTION creation_pcr;
+
     struct {
         UINT8 b :1;
         UINT8 i :1;
@@ -51,19 +60,30 @@ struct tpm_create_ctx {
 
 static tpm_create_ctx ctx = {
         .object = { .alg = DEFAULT_KEY_ALG },
+        .creation_pcr = { .count = 0 },
 };
 
+static bool load_outside_info(TPM2B_DATA *outside_info) {
+
+    outside_info->size = sizeof(outside_info->buffer);
+    return tpm2_util_bin_from_hex_or_file(ctx.outside_info_data,
+            &outside_info->size,
+            outside_info->buffer);
+}
+
 static tool_rc create(ESYS_CONTEXT *ectx) {
 
     tool_rc rc = tool_rc_general_error;
 
-    TPM2B_DATA outside_info = TPM2B_EMPTY_INIT;
-    TPML_PCR_SELECTION creation_pcr = { .count = 0 };
     TPM2B_PUBLIC *out_public;
     TPM2B_PRIVATE *out_private;
 
     ESYS_TR object_handle = ESYS_TR_NONE;
-    if (ctx.object.ctx_path) {
+    if (ctx.object.ctx_path &&
+        (!ctx.object.creation_data_file &&
+         !ctx.object.creation_ticket_file &&
+         !ctx.object.creation_hash_file)
+       ) {
 
         size_t offset = 0;
         TPM2B_TEMPLATE template = { .size = 0 };
@@ -83,19 +103,77 @@ static tool_rc create(ESYS_CONTEXT *ectx) {
             return tmp_rc;
         }
     } else {
-        TPM2B_CREATION_DATA *creation_data;
-        TPM2B_DIGEST *creation_hash;
-        TPMT_TK_CREATION *creation_ticket;
+        /*
+         * Outside data is optional. If not specified default to 0
+         */
+        bool result = true;
+        TPM2B_DATA outside_info = TPM2B_EMPTY_INIT;
+        if (ctx.outside_info_data) {
+            result = load_outside_info(&outside_info);
+        }
+        if (!result) {
+            return tool_rc_general_error;
+        }
+
+        TPM2B_CREATION_DATA *creation_data = NULL;
+        TPM2B_DIGEST *creation_hash = NULL;
+        TPMT_TK_CREATION *creation_ticket = NULL;
         tool_rc tmp_rc = tpm2_create(ectx, &ctx.parent.object,
                 &ctx.object.sensitive, &ctx.object.public, &outside_info,
-                &creation_pcr, &out_private, &out_public, &creation_data,
+                &ctx.creation_pcr, &out_private, &out_public, &creation_data,
                 &creation_hash, &creation_ticket);
         if (tmp_rc != tool_rc_success) {
             return tmp_rc;
         }
+
+        if (ctx.object.creation_data_file && creation_data->size) {
+            result = files_save_creation_data(creation_data,
+                ctx.object.creation_data_file);
+        }
+        if (!result) {
+            LOG_ERR("Failed saving creation data.");
+            tmp_rc = tool_rc_general_error;
+            goto create_out;
+        }
+
+        if (ctx.object.creation_ticket_file && creation_ticket->digest.size) {
+            result = files_save_creation_ticket(creation_ticket,
+                ctx.object.creation_ticket_file);
+        }
+        if (!result) {
+            LOG_ERR("Failed saving creation ticket.");
+            tmp_rc = tool_rc_general_error;
+            goto create_out;
+        }
+
+        if (ctx.object.creation_hash_file && creation_hash->size) {
+            result = files_save_digest(creation_hash,
+                ctx.object.creation_hash_file);
+        }
+        if (!result) {
+            LOG_ERR("Failed saving creation hash.");
+            tmp_rc = tool_rc_general_error;
+            goto create_out;
+        }
+
+create_out:
         free(creation_data);
         free(creation_hash);
         free(creation_ticket);
+        if (tmp_rc != tool_rc_success) {
+            return tmp_rc;
+        }
+    }
+
+    if (ctx.object.template_data_path) {
+        bool res = files_save_template(&ctx.object.public.publicArea,
+        ctx.object.template_data_path);
+
+        if (!res) {
+            LOG_ERR("Could not save public template to file.");
+            rc = tool_rc_general_error;
+            goto out;
+        }
     }
 
     tpm2_util_public_to_yaml(out_public, NULL);
@@ -170,6 +248,27 @@ static bool on_option(char key, char *value) {
     case 'c':
         ctx.object.ctx_path = value;
         break;
+    case 0:
+        ctx.object.creation_data_file = value;
+        break;
+    case 1:
+        ctx.object.template_data_path = value;
+        break;
+    case 't':
+        ctx.object.creation_ticket_file = value;
+        break;
+    case 'd':
+        ctx.object.creation_hash_file = value;
+        break;
+    case 'q':
+        ctx.outside_info_data = value;
+        break;
+    case 'l':
+        if (!pcr_parse_selections(value, &ctx.creation_pcr)) {
+            LOG_ERR("Could not parse pcr selections, got: \"%s\"", value);
+            return false;
+        }
+        break;
     };
 
     return true;
@@ -189,9 +288,15 @@ bool tpm2_tool_onstart(tpm2_options **opts) {
       { "private",        required_argument, NULL, 'r' },
       { "parent-context", required_argument, NULL, 'C' },
       { "key-context",    required_argument, NULL, 'c' },
+      { "creation-data",  required_argument, NULL,  0  },
+      { "template-data",  required_argument, NULL,  1  },
+      { "creation-ticket",required_argument, NULL, 't' },
+      { "creation-hash",  required_argument, NULL, 'd' },
+      { "outside-info",   required_argument, NULL, 'q' },
+      { "pcr-list",       required_argument, NULL, 'l' },
     };
 
-    *opts = tpm2_options_new("P:p:g:G:a:i:L:u:r:C:c:", ARRAY_LEN(topts), topts,
+    *opts = tpm2_options_new("P:p:g:G:a:i:L:u:r:C:c:t:d:q:l:", ARRAY_LEN(topts), topts,
             on_option, NULL, 0);
 
     return *opts != NULL;
