@@ -199,10 +199,9 @@ static tool_rc create_ek_handle(ESYS_CONTEXT *ectx) {
             return rc;
         }
 
-        TSS2_RC rval = Esys_FlushContext(ectx, ctx.objdata.out.handle);
-        if (rval != TSS2_RC_SUCCESS) {
-            LOG_PERR(Esys_FlushContext, rval);
-            return tool_rc_from_tpm(rval);
+        rc = tpm2_flush_context(ectx, ctx.objdata.out.handle);
+        if (rc != tool_rc_success) {
+            return rc;
         }
     } else {
         /* If it wasn't persistent, save a context for future tool interactions */
@@ -347,7 +346,7 @@ tool_rc tpm2_tool_onrun(ESYS_CONTEXT *ectx, tpm2_option_flags flags) {
          * to use and tell them what it is.
          */
         rc = tpm2_capability_find_vacant_persistent_handle(ectx,
-                &ctx.ctx_obj.handle);
+                false, &ctx.ctx_obj.handle);
         if (rc != tool_rc_success) {
             LOG_ERR("handle/-H passed with a value '-' but unable to find a"
                     " vacant persistent handle!");
