@@ -1,5 +1,6 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
 
+#include <assert.h>
 #include <errno.h>
 #include <stdbool.h>
 #include <stdio.h>
@@ -13,6 +14,8 @@
 #include "tpm2_auth_util.h"
 #include "tpm2_options.h"
 
+#define MAX_INPUT_DATA_SIZE UINT16_MAX
+
 typedef struct tpm_encrypt_decrypt_ctx tpm_encrypt_decrypt_ctx;
 struct tpm_encrypt_decrypt_ctx {
     struct {
@@ -23,10 +26,10 @@ struct tpm_encrypt_decrypt_ctx {
 
     TPMI_YES_NO is_decrypt;
 
-    uint8_t input_data[UINT16_MAX];
+    uint8_t input_data[MAX_INPUT_DATA_SIZE];
     uint16_t input_data_size;
-    char *input_path;
 
+    const char *input_path;
     char *out_file_path;
 
     uint8_t padded_block_len;
@@ -41,7 +44,7 @@ struct tpm_encrypt_decrypt_ctx {
 
 static tpm_encrypt_decrypt_ctx ctx = {
     .mode = TPM2_ALG_NULL,
-    .input_data_size = 0,
+    .input_data_size = MAX_INPUT_DATA_SIZE,
     .padded_block_len = TPM2_MAX_SYM_BLOCK_SIZE,
     .is_padding_option_enabled = false,
 };
@@ -49,7 +52,7 @@ static tpm_encrypt_decrypt_ctx ctx = {
 static tool_rc readpub(ESYS_CONTEXT *ectx, TPM2B_PUBLIC **public) {
 
     return tpm2_readpublic(ectx, ctx.encryption_key.object.tr_handle,
-            ESYS_TR_NONE, ESYS_TR_NONE, ESYS_TR_NONE, public, NULL, NULL);
+            public, NULL, NULL);
 }
 
 static bool evaluate_pkcs7_padding_requirements(uint16_t remaining_bytes,
@@ -190,6 +193,8 @@ static tool_rc encrypt_decrypt(ESYS_CONTEXT *ectx, TPM2B_IV *iv_start) {
          * This copy is also output from the tool for further chaining.
          */
         if (ctx.mode != TPM2_ALG_ECB) {
+            assert(iv_in);
+            assert(iv_out);
             *iv_in = *iv_out;
             free(iv_out);
         }
@@ -213,7 +218,7 @@ static tool_rc encrypt_decrypt(ESYS_CONTEXT *ectx, TPM2B_IV *iv_start) {
      * iv_in here is the copy of final iv_out from the loop above.
      */
     result =
-            (ctx.iv.out) ?
+            (ctx.iv.out && iv_in) ?
                     files_save_bytes_to_file(ctx.iv.out, iv_in->buffer,
                             iv_in->size) :
                     true;
@@ -338,20 +343,7 @@ static bool on_args(int argc, char *argv[]) {
         return false;
     }
 
-    bool result;
-    long unsigned int filesize;
     ctx.input_path = argv[0];
-    result = files_get_file_size_path(ctx.input_path, &filesize);
-    if (!result) {
-        LOG_ERR("Input file size could not be retrieved.");
-        return false;
-    }
-    if (filesize > UINT16_MAX) {
-        LOG_ERR("File size bigger than UINT16_MAX");
-        return false;
-    }
-
-    ctx.input_data_size = filesize;
 
     return true;
 }
@@ -383,12 +375,6 @@ tool_rc tpm2_tool_onrun(ESYS_CONTEXT *ectx, tpm2_option_flags flags) {
         return tool_rc_option_error;
     }
 
-    bool result = files_load_bytes_from_buffer_or_file_or_stdin(NULL,
-            ctx.input_path, &ctx.input_data_size, ctx.input_data);
-    if (!result) {
-        return tool_rc_general_error;
-    }
-
     tool_rc rc = tpm2_util_object_load_auth(ectx, ctx.encryption_key.ctx_path,
             ctx.encryption_key.auth_str, &ctx.encryption_key.object, false,
             TPM2_HANDLE_ALL_W_NV);
@@ -397,6 +383,12 @@ tool_rc tpm2_tool_onrun(ESYS_CONTEXT *ectx, tpm2_option_flags flags) {
         return rc;
     }
 
+    bool result = files_load_bytes_from_buffer_or_file_or_stdin(NULL,
+            ctx.input_path, &ctx.input_data_size, ctx.input_data);
+    if (!result) {
+        return tool_rc_general_error;
+    }
+
     TPM2B_IV iv = { .size = sizeof(iv.buffer), .buffer = { 0 } };
     result = setup_alg_mode_and_iv_and_padding(ectx, &iv);
     if (!result) {
