@@ -640,12 +640,12 @@ static bool dump_command_attrs(TPMA_CC tpma_cc) {
     tpm2_tool_output("  flushed:      %s\n",
             prop_str (tpma_cc & TPMA_CC_FLUSHED));
     tpm2_tool_output("  cHandles:     0x%x\n",
-            tpma_cc & TPMA_CC_CHANDLES_MASK >> TPMA_CC_CHANDLES_SHIFT);
+            (tpma_cc & TPMA_CC_CHANDLES_MASK) >> TPMA_CC_CHANDLES_SHIFT);
     tpm2_tool_output("  rHandle:      %s\n",
             prop_str (tpma_cc & TPMA_CC_RHANDLE));
     tpm2_tool_output("  V:            %s\n", prop_str (tpma_cc & TPMA_CC_V));
     tpm2_tool_output("  Res:          0x%x\n",
-            tpma_cc & TPMA_CC_RES_MASK >> TPMA_CC_RES_SHIFT);
+            (tpma_cc & TPMA_CC_RES_MASK) >> TPMA_CC_RES_SHIFT);
     return true;
 }
 /*
@@ -784,10 +784,9 @@ static bool dump_tpm_capability(TPMU_CAPABILITIES *capabilities) {
 
 static bool on_option(char key, char *value) {
 
+    UNUSED(value);
+
     switch (key) {
-    case 'c':
-        options.capability_string = value;
-        break;
     case 'l':
         options.list = true;
     }
@@ -824,7 +823,7 @@ tool_rc tpm2_tool_onrun(ESYS_CONTEXT *context, tpm2_option_flags flags) {
     UNUSED(flags);
 
     if (options.list && options.capability_string) {
-        LOG_ERR("Cannot specify -l with -c.");
+        LOG_ERR("Cannot specify -l with a capability group.");
         return tool_rc_option_error;
     }
 
@@ -834,7 +833,7 @@ tool_rc tpm2_tool_onrun(ESYS_CONTEXT *context, tpm2_option_flags flags) {
         return tool_rc_success;
     }
 
-    /* List a capability, ie -c <arg> option */
+    /* List a capability, ie <capability group> option */
     TPMS_CAPABILITY_DATA *capability_data = NULL;
 
     bool ret = sanity_check_capability_opts();
