@@ -9,6 +9,7 @@
 
 #include "files.h"
 #include "log.h"
+#include "tpm2.h"
 #include "tpm2_alg_util.h"
 #include "tpm2_identity_util.h"
 #include "tpm2_options.h"
@@ -93,12 +94,9 @@ static tool_rc make_external_credential_and_save(void) {
      * Generate and encrypt seed
      */
     TPM2B_DIGEST seed = TPM2B_TYPE_INIT(TPM2B_DIGEST, buffer);
-    seed.size = tpm2_alg_util_get_hash_size(name_alg);
-    RAND_bytes(seed.buffer, seed.size);
-
     TPM2B_ENCRYPTED_SECRET encrypted_seed = TPM2B_EMPTY_INIT;
     unsigned char label[10] = { 'I', 'D', 'E', 'N', 'T', 'I', 'T', 'Y', 0 };
-    bool res = tpm2_identity_util_encrypt_seed_with_public_key(&seed,
+    bool res = tpm2_identity_util_share_secret_with_public_key(&seed,
             &ctx.public, label, 9, &encrypted_seed);
     if (!res) {
         LOG_ERR("Failed Seed Encryption\n");
@@ -170,27 +168,25 @@ static tool_rc make_credential_and_save(ESYS_CONTEXT *ectx) {
     TPM2B_ID_OBJECT *cred_blob;
     TPM2B_ENCRYPTED_SECRET *secret;
     ESYS_TR tr_handle = ESYS_TR_NONE;
-    UINT32 rval;
 
-    rval = Esys_LoadExternal(ectx, ESYS_TR_NONE, ESYS_TR_NONE, ESYS_TR_NONE,
+    tool_rc rc = tpm2_loadexternal(ectx,
             NULL, &ctx.public, TPM2_RH_NULL, &tr_handle);
-    if (rval != TPM2_RC_SUCCESS) {
-        LOG_PERR(Esys_LoadExternal, rval);
-        return tool_rc_from_tpm(rval);
+    if (rc != tool_rc_success) {
+        return rc;
     }
 
-    rval = Esys_MakeCredential(ectx, tr_handle, ESYS_TR_NONE, ESYS_TR_NONE,
-            ESYS_TR_NONE, &ctx.credential, &ctx.object_name, &cred_blob,
+    rc = tpm2_makecredential(ectx, tr_handle,
+            &ctx.credential, &ctx.object_name, &cred_blob,
             &secret);
-    if (rval != TPM2_RC_SUCCESS) {
-        LOG_PERR(Esys_MakeCredential, rval);
-        return tool_rc_from_tpm(rval);
+    if (rc != tool_rc_success) {
+        return rc;
     }
 
-    rval = Esys_FlushContext(ectx, tr_handle);
-    if (rval != TPM2_RC_SUCCESS) {
-        LOG_PERR(Esys_FlushContext, rval);
-        return tool_rc_from_tpm(rval);
+    rc = tpm2_flush_context(ectx, tr_handle);
+    if (rc != tool_rc_success) {
+        free(cred_blob);
+        free(secret);
+        return rc;
     }
 
     bool ret = write_cred_and_secret(ctx.out_file_path, cred_blob, secret);
