@@ -1,6 +1,7 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
 
 #include "log.h"
+#include "tpm2.h"
 #include "tpm2_options.h"
 
 typedef struct tpm_selftest_ctx tpm_selftest_ctx;
@@ -11,18 +12,6 @@ struct tpm_selftest_ctx {
 
 static tpm_selftest_ctx ctx;
 
-static tool_rc tpm_selftest(ESYS_CONTEXT *ectx) {
-    TSS2_RC rval = Esys_SelfTest(ectx, ESYS_TR_NONE, ESYS_TR_NONE, ESYS_TR_NONE,
-            ctx.fulltest);
-    if (rval != TSS2_RC_SUCCESS) {
-        LOG_ERR("TPM SelfTest failed !");
-        LOG_PERR(Esys_SelfTest, rval);
-        return tool_rc_from_tpm(rval);
-    }
-
-    return tool_rc_success;
-}
-
 static bool on_option(char key, char *value) {
 
     UNUSED(value);
@@ -56,5 +45,5 @@ tool_rc tpm2_tool_onrun(ESYS_CONTEXT *ectx, tpm2_option_flags flags) {
 
     UNUSED(flags);
 
-    return tpm_selftest(ectx);
+    return tpm2_selftest(ectx, ctx.fulltest);
 }
